"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HostedWidgetApi = void 0;
const ElectronUtils_1 = require("../utils/ElectronUtils");
const Channel_1 = require("./Channel");
class HostedWidgetApi {
    /**
     * 移除组件
     * @param id
     */
    static async removeHostedWidget(id) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.REMOVE_HOSTED_WIDGET, id);
    }
    /**
     * 通过组件名移除已添加的组件
     * @param name  组件名
     */
    static async removeHostedWidgetByName(name) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.REMOVE_HOSTED_WIDGET_BY_NAME, name);
    }
    /**
     * 获取已添加的组件
     * @param name  组件名，可以不传
     */
    static async getHostedWidgets(name) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.GET_HOSTED_WIDGETS, name);
    }
    static async getHostedWidget(id) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.GET_HOSTED_WIDGET, id);
    }
    /**
     * Opens the dev tools for a widget with the specified ID.
     *
     * @param {string} widgetId - The ID of the widget to open the dev tools for.
     * @return {Promise} A Promise that resolves when the dev tools are opened.
     */
    static async openDevTools(widgetId) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.OPEN_DEV_TOOLS, widgetId);
    }
    static async openConfigRoute(widgetId, params) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.OPEN_CONFIG_ROUTE, widgetId, params);
    }
    /**
     * 注册激活、呼出、置顶组件快捷键
     * @param widgetId  组件id
     * @param shortcut  如果传空或者不传，则会取消快捷键。更多快捷键配置，请查看Accelerator用法
     *                  https://www.electronjs.org/docs/latest/api/accelerator
     */
    static async registerActiveShortcut(widgetId, shortcut) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.REGISTER_ACTIVE_SHORTCUT, widgetId, shortcut);
    }
    static async setProxy(widgetId, proxy) {
        var _a;
        return (_a = ElectronUtils_1.ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel_1.Channel.HOSTED_WIDGET, this.SET_PROXY, widgetId, proxy);
    }
}
exports.HostedWidgetApi = HostedWidgetApi;
HostedWidgetApi.REMOVE_HOSTED_WIDGET = "remove-hosted-widget";
HostedWidgetApi.REMOVE_HOSTED_WIDGET_BY_NAME = "remove-hosted-widget-by-name";
HostedWidgetApi.GET_HOSTED_WIDGETS = "get-hosted-widgets";
HostedWidgetApi.GET_HOSTED_WIDGET = "get-hosted-widget";
HostedWidgetApi.OPEN_DEV_TOOLS = "open-dev-tools";
HostedWidgetApi.REGISTER_ACTIVE_SHORTCUT = "register-active-shortcut";
HostedWidgetApi.SET_PROXY = "SET_PROXY";
HostedWidgetApi.UPDATE = "UPDATE";
HostedWidgetApi.OPEN_CONFIG_ROUTE = "open-config-route";
