import { Channel } from "./Channel";
import { ElectronUtils } from "../utils/ElectronUtils";
export class BrowserWindowApi {
    static async setIgnoreMouseEvent(ignore) {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.IGNORE_MOUSE_EVENT, ignore);
    }
    static async show() {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.WINDOW_VISIBILITY, true);
    }
    static async hide() {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.WINDOW_VISIBILITY, false);
    }
    static async center() {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.CENTER, false);
    }
    /**
     * @deprecated
     * @param show
     */
    static async setWindowVisibility(show) {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.WINDOW_VISIBILITY, show);
    }
    static async setAlwaysOnTop(alwaysOnTop) {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.ALWAYS_ON_TOP, alwaysOnTop);
    }
    static async isAlwaysOnTop() {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.IS_ALWAYS_ON_TOP);
    }
    static async openUrl(url) {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.OPEN_URL, url);
    }
    static async moveTop() {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.MOVE_TOP);
    }
    static async openDevTools() {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.OPEN_DEV_TOOLS);
    }
    /**
     * 设置窗口位置
     * @param x
     * @param y
     * @param animation 动画只在mac系统有效
     */
    static async setPosition(x, y, animation) {
        await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.SET_POSITION, x, y, animation);
    }
    static async getPosition() {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.GET_POSITION);
    }
    static async blur() {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.BLUR);
    }
    static async focus() {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.FOCUS);
    }
    /**
     * 设置窗口是否可以拉伸
     * @param resizable
     */
    static async setResizable(resizable) {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.SET_RESIZABLE, resizable);
    }
    static async getBounds() {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.GET_BOUNDS);
    }
    static async setBounds(bounds, animate) {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.SET_BOUNDS, bounds, animate);
    }
    static async alignToScreen(align) {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.ALIGN_TO_SCREEN, align);
    }
    /**
     * 通过url检测窗口是否存在
     * @param url
     */
    static async existsByUrl(url) {
        return await ElectronUtils.invoke(Channel.BROWSER_WINDOW, this.EXISTS_BY_URL, url);
    }
}
BrowserWindowApi.IGNORE_MOUSE_EVENT = "ignore-mouse-event";
BrowserWindowApi.WINDOW_VISIBILITY = "window-visibility";
BrowserWindowApi.CENTER = "center";
BrowserWindowApi.ALWAYS_ON_TOP = "always-on-top";
BrowserWindowApi.IS_ALWAYS_ON_TOP = "is-always-on-top";
BrowserWindowApi.OPEN_URL = "open-url";
BrowserWindowApi.MOVE_TOP = "move-top";
BrowserWindowApi.OPEN_DEV_TOOLS = "open-dev-tools";
BrowserWindowApi.SET_POSITION = "set-position";
BrowserWindowApi.GET_POSITION = "get-position";
BrowserWindowApi.BLUR = "blur";
BrowserWindowApi.FOCUS = "focus";
BrowserWindowApi.SET_RESIZABLE = "set-resizable";
BrowserWindowApi.GET_BOUNDS = "get-bounds";
BrowserWindowApi.SET_BOUNDS = "set-bounds";
BrowserWindowApi.ALIGN_TO_SCREEN = "align-to-screen";
BrowserWindowApi.EXISTS_BY_URL = "exists-by-url";
BrowserWindowApi.SHOW = "show";
